Icelandair - Island rejser fra København, billige flybilletter og pakkerejser til USA & Island | Icelandair
Description: Saga Club

## Join our Frequent Flyer Program,

## Icelandair Saga Club

### Numerous benefits for our Frequent Flyers

Join here
prev next

- Welcome
- Join Now

# Saga Club

Username or 10 digit Saga Card number Kræves
Password Kræves
Forgot your details?
Register points from Icelandair flights

Or

Username
Password

## Join Now

Join us now and become a member in our Saga Club. Start earning Saga Points today and enjoy the best we have to offer. Individuals 12 years and older are eligible for membership.

Join now

- My Account
- Book a Flight
- Book a Hotel
- Buy Saga Card
- Buy Saga Points
- Donate Saga Points

# Saga Club

# Discover the benefits

# Enjoy more